<?php

namespace Drupal\acquia_search\EventSubscriber\PossibleCores;

use Drupal\acquia_connector\Subscription;
use Drupal\acquia_search\AcquiaSearchApiClient;
use Drupal\acquia_search\AcquiaSearchEvents;
use Drupal\acquia_search\Event\AcquiaPossibleCoresEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Fallback Default core to readonly production server.
 *
 * This class remains for backwards compatibility only. As of Acquia Search 3.2
 * it has no independent functionality.
 *
 * @deprecated This class has moved to acquia_search_defaults. Do not extend!
 * @see \Drupal\acquia_search_defaults\EventSubscriber\PossibleCores\AcquiaHosting
 */
class DefaultCore implements EventSubscriberInterface {

  /**
   * Site Folder Name.
   *
   * @var false|string
   */
  protected $sitesFolderName;

  /**
   * Acquia subscription service.
   *
   * @var \Drupal\acquia_connector\Subscription
   */
  protected $subscription;

  /**
   * Acquia Search API Client.
   *
   * @var \Drupal\acquia_search\AcquiaSearchApiClient
   */
  protected $acquiaSearchApiClient;

  /**
   * Get Possible Cores from Cloud Constructor.
   *
   * @param \Drupal\acquia_connector\Subscription $subscription
   *   Acquia Subscription Service.
   * @param \Drupal\acquia_search\AcquiaSearchApiClient $search_api_client
   *   Acquia Search API Service.
   * @param \Drupal\Core\SitePathFactory|string $site_path
   *   Drupal Site Path.
   */
  public function __construct(Subscription $subscription, AcquiaSearchApiClient $search_api_client, $site_path) {
    $sites_foldername = substr($site_path, strrpos($site_path, '/') + 1);
    $this->sitesFolderName = preg_replace('/[^a-zA-Z0-9]+/', '', $sites_foldername);
    $this->subscription = $subscription;
    $this->acquiaSearchApiClient = $search_api_client;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    // phpcs:ignore
    $events[AcquiaSearchEvents::GET_POSSIBLE_CORES][] = ['onGetPossibleCores', -1000];
    return $events;
  }

  /**
   * Gets a prebuilt Settings object from Drupal's settings file.
   *
   * @param \Drupal\acquia_search\Event\AcquiaPossibleCoresEvent $event
   *   The dispatched event.
   *
   * @see \Drupal\acquia_connector\Settings
   */
  public function onGetPossibleCores(AcquiaPossibleCoresEvent $event) {
    return;
  }
}
